@@ -1,5 +1,10 @@
 import gc
-from time import time
+import sys
+
+if sys.platform == 'win32':
+    from time import clock as time
+else:
+    from time import time
 
 from nozdormu.util import format_time
 
